fn hash_rustc_version(
bcx: &BuildContext<'_, '_>,
hasher: &mut StableHasher,
unit: &Unit,
)Expand description
Hash the version of rustc being used during the build process.
fn hash_rustc_version(
bcx: &BuildContext<'_, '_>,
hasher: &mut StableHasher,
unit: &Unit,
)Hash the version of rustc being used during the build process.