CompileMode

Enum CompileMode 

pub enum CompileMode {
    Test,
    Build,
    Check {
        test: bool,
    },
    Bench,
    Doc {
        deps: bool,
    },
    Doctest,
    RunCustomBuild,
}
The general “mode” for what to do. This is used for two purposes. The commands themselves pass this in to compile_ws to tell it the general execution strategy. This influences the default targets selected. The other use is in the Unit struct to indicate what is being done with a specific target.

Variants



Test

A target being built for a test.



Build

Building a target with rustc (lib or bin).



Check

Building a target with rustc to emit rmeta metadata only. If test is true, then it is also compiled with --test to check it like a test.

Fields

test: bool


Bench

Used to indicate benchmarks should be built. This is not used in Unit, because it is essentially the same as Test (indicating --test should be passed to rustc) and by using Test instead it allows some de-duping of Units to occur.



Doc

A target that will be documented with rustdoc. If deps is true, then it will also document all dependencies.

Fields

deps: bool


Doctest

A target that will be tested with rustdoc.



RunCustomBuild

A marker for Units that represent the execution of a build.rs script.

Implementations

Source

impl CompileMode

pub fn is_check(self) -> bool

Returns true if the unit is being checked.

pub fn is_doc(self) -> bool

Returns true if this is generating documentation.

pub fn is_doc_test(self) -> bool

Returns true if this a doc test.

pub fn is_any_test(self) -> bool

Returns true if this is any type of test (test, benchmark, doc test, or check test).

pub fn is_rustc_test(self) -> bool

Returns true if this is something that passes --test to rustc.

pub fn is_run_custom_build(self) -> bool

Returns true if this is the execution of a build.rs script.

pub fn all_modes() -> &'static [CompileMode]

List of all modes (currently used by cargo clean -p for computing all possible outputs).