pub struct BuildScriptOutputs { /* private fields */ }Expand description
Map of packages to build script output.
This initially starts out as empty. Overridden build scripts get
inserted during build_map. The rest of the entries are added
immediately after each build script runs.
The Metadata is the unique metadata hash for the RunCustomBuild Unit of
the package. It needs a unique key, since the build script can be run
multiple times with different profiles or features. We can’t embed a
Unit because this structure needs to be shareable between threads.
Implementations