TargetInfo

Struct TargetInfo 

pub struct TargetInfo {
    pub sysroot: PathBuf,
    pub sysroot_host_libdir: PathBuf,
    pub sysroot_target_libdir: PathBuf,
    pub rustflags: Vec<String>,
    pub rustdocflags: Vec<String>,
    /* private fields */
}
Information about the platform target gleaned from querying rustc.

RustcTargetData keeps two of these, one for the host and one for the target. If no target is specified, it uses a clone from the host.

Fields

sysroot: PathBuf

Path to the sysroot.

sysroot_host_libdir: PathBuf

Path to the “lib” or “bin” directory that rustc uses for its dynamic libraries.

sysroot_target_libdir: PathBuf

Path to the “lib” directory in the sysroot which rustc uses for linking target libraries.

rustflags: Vec<String>

Extra flags to pass to rustc, see env_args.

rustdocflags: Vec<String>

Extra flags to pass to rustdoc, see env_args.

Implementations

Source

impl TargetInfo

pub fn new( config: &Config, requested_kind: CompileKind, rustc: &Rustc, kind: CompileKind, ) -> CargoResult<TargetInfo>

pub fn cfg(&self) -> &[Cfg]

All the target cfg settings.

pub fn file_types( &self, crate_type: &str, flavor: FileFlavor, kind: &TargetKind, target_triple: &str, ) -> CargoResult<Option<Vec<FileType>>>

Returns the list of file types generated by the given crate type.

Returns None if the target does not support the given crate type.