pub struct Unit<'a> { /* private fields */ }Expand description
All information needed to define a unit.
A unit is an object that has enough information so that cargo knows how to build it.
For example, if your package has dependencies, then every dependency will be built as a library
unit. If your package is a library, then it will be built as a library unit as well, or if it
is a binary with main.rs, then a binary will be output. There are also separate unit types
for testing and checking, amongst others.
The unit also holds information about all possible metadata about the package in pkg.
A unit needs to know extra information in addition to the type and root source file. For example, it needs to know the target architecture (OS, chip arch etc.) and it needs to know whether you want a debug or release build. There is enough information in this struct to figure all that out.