pub struct UnitDep<'a> {
pub unit: Unit<'a>,
pub unit_for: UnitFor,
pub extern_crate_name: InternedString,
pub public: bool,
pub noprelude: bool,
}Expand description
A unit dependency.
Fields
unit: Unit<'a>The dependency unit.
unit_for: UnitForThe purpose of this dependency (a dependency for a test, or a build script, etc.).
extern_crate_name: InternedStringThe name the parent uses to refer to this dependency.
public: boolWhether or not this is a public dependency.
noprelude: boolIf true, the dependency should not be added to Rust’s prelude.