Function cargo::core::global_cache_tracker::to_timestamp
source · fn to_timestamp(t: &SystemTime) -> u64Expand description
Converts a SystemTime to a Timestamp which can be stored in the database.
fn to_timestamp(t: &SystemTime) -> u64Converts a SystemTime to a Timestamp which can be stored in the database.