Struct cargo::core::package::Package
[−]
[src]
pub struct Package {
// some fields omitted
}Information about a package that is available somewhere in the file system.
A package is a Cargo.toml file plus all the files that are part of it.