pub struct ResolvedFeatures { /* private fields */ }Expand description
Set of all activated features for all packages in the resolve graph.
Implementations
Sourceimpl ResolvedFeatures
impl ResolvedFeatures
Sourcepub fn activated_features(
&self,
pkg_id: PackageId,
features_for: FeaturesFor,
) -> Vec<InternedString>
pub fn activated_features( &self, pkg_id: PackageId, features_for: FeaturesFor, ) -> Vec<InternedString>
Returns the list of features that are enabled for the given package.
Sourcepub fn activated_features_unverified(
&self,
pkg_id: PackageId,
features_for: FeaturesFor,
) -> Vec<InternedString>
pub fn activated_features_unverified( &self, pkg_id: PackageId, features_for: FeaturesFor, ) -> Vec<InternedString>
Variant of activated_features that returns an empty Vec if this is
not a valid pkg_id/is_build combination. Used in places which do
not know which packages are activated (like cargo clean).