Struct cargo::core::resolver::EncodablePackageId
[−]
[src]
pub struct EncodablePackageId {
// some fields omitted
}Trait Implementations
impl Encodable for EncodablePackageId[src]
impl Decodable for EncodablePackageId[src]
fn decode<D: Decoder>(d: &mut D) -> Result<EncodablePackageId, D::Error>
Derived Implementations
impl Eq for EncodablePackageId[src]
impl PartialEq for EncodablePackageId[src]
fn eq(&self, __arg_0: &EncodablePackageId) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &EncodablePackageId) -> bool
This method tests for !=.
impl Ord for EncodablePackageId[src]
fn cmp(&self, __arg_0: &EncodablePackageId) -> Ordering
This method returns an Ordering between self and other. Read more
impl PartialOrd for EncodablePackageId[src]
fn partial_cmp(&self, __arg_0: &EncodablePackageId) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, __arg_0: &EncodablePackageId) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, __arg_0: &EncodablePackageId) -> bool
This method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, __arg_0: &EncodablePackageId) -> bool
This method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, __arg_0: &EncodablePackageId) -> bool
This method tests greater than or equal to (for self and other) and is used by the >= operator. Read more