pub enum QueryKind {
Exact,
Fuzzy,
}Expand description
Defines how a dependency query will be performed for a Source.
Variants
Exact
A query for packages exactly matching the given dependency requirement.
Each source gets to define what exact means for it.
Fuzzy
A query for packages close to the given dependency requirement.
Each source gets to define what close means for it.
Path/Git sources may return all dependencies that are at that URI,
whereas an Registry source may return dependencies that have the same
canonicalization.