PackageIdSpec

Struct PackageIdSpec 

pub struct PackageIdSpec { /* private fields */ }
Some or all of the data required to identify a package:

  1. the package name (a String, required)
  2. the package version (a Version, optional)
  3. the package source (a Url, optional)

If any of the optional fields are omitted, then the package ID may be ambiguous, there may be more than one package/version/url combo that will match. However, often just the name is sufficient to uniquely define a package ID.

Implementations

Source

impl PackageIdSpec

pub fn parse(spec: &str) -> CargoResult<PackageIdSpec>

Parses a spec string and returns a PackageIdSpec if the string was valid.

Examples

Some examples of valid strings

use cargo::core::PackageIdSpec;

let specs = vec![
    "https://crates.io/foo#1.2.3",
    "https://crates.io/foo#bar:1.2.3",
    "crates.io/foo",
    "crates.io/foo#1.2.3",
    "crates.io/foo#bar",
    "crates.io/foo#bar:1.2.3",
    "foo",
    "foo:1.2.3",
];
for spec in specs {
    assert!(PackageIdSpec::parse(spec).is_ok());
}
pub fn query_str<I>(spec: &str, i: I) -> CargoResult<PackageId>
where I: IntoIterator<Item = PackageId>,

Roughly equivalent to PackageIdSpec::parse(spec)?.query(i)

pub fn from_package_id(package_id: PackageId) -> PackageIdSpec

Convert a PackageId to a PackageIdSpec, which will have both the Version and Url fields filled in.

pub fn name(&self) -> InternedString

pub fn version(&self) -> Option<&Version>

pub fn url(&self) -> Option<&Url>

pub fn set_url(&mut self, url: Url)

pub fn matches(&self, package_id: PackageId) -> bool

Checks whether the given PackageId matches the PackageIdSpec.

pub fn query<I>(&self, i: I) -> CargoResult<PackageId>
where I: IntoIterator<Item = PackageId>,

Checks a list of PackageIds to find 1 that matches this PackageIdSpec. If 0, 2, or more are found, then this returns an error.