pub struct WorkspaceRootConfig { /* private fields */ }Expand description
Intermediate configuration of a workspace root in a manifest.
Knows the Workspace Root path, as well as members and exclude lists of path patterns, which
together tell if some path is recognized as a member by this root or not.
Implementations