pub enum FeatureValue {
Feature(InternedString),
Crate(InternedString),
CrateFeature(InternedString, InternedString),
}Expand description
FeatureValue represents the types of dependencies a feature can have:
- Another feature
- An optional dependency
- A feature in a dependency
The selection between these 3 things happens as part of the construction of the FeatureValue.
Variants
Implementations
Sourceimpl FeatureValue
impl FeatureValue
pub fn new(feature: InternedString, s: &Summary) -> FeatureValue
pub fn to_string(&self, s: &Summary) -> String