pub struct UnitDep {
pub unit: Unit,
pub unit_for: UnitFor,
pub extern_crate_name: InternedString,
pub dep_name: Option<InternedString>,
pub public: bool,
pub noprelude: bool,
}Expand description
A unit dependency.
Fields
unit: UnitThe dependency unit.
unit_for: UnitForThe purpose of this dependency (a dependency for a test, or a build script, etc.). Do not use this after the unit graph has been built.
extern_crate_name: InternedStringThe name the parent uses to refer to this dependency.
dep_name: Option<InternedString>If Some, the name of the dependency if renamed in toml.
It’s particularly interesting to artifact dependencies which rely on it
for naming their environment variables. Note that the extern_crate_name
cannot be used for this as it also may be the build target itself,
which isn’t always the renamed dependency name.
public: boolWhether or not this is a public dependency.
noprelude: boolIf true, the dependency should not be added to Rust’s prelude.