struct SourceIdInner {
url: Url,
canonical_url: CanonicalUrl,
kind: SourceKind,
precise: Option<String>,
name: Option<String>,
alt_registry_key: Option<String>,
}Expand description
The interned version of SourceId to avoid excessive clones and borrows.
Values are cached in SOURCE_ID_CACHE once created.
Fields
url: UrlThe source URL.
canonical_url: CanonicalUrlThe canonical version of the above url. See CanonicalUrl to learn
why it is needed and how it normalizes a URL.
kind: SourceKindThe source kind.
precise: Option<String>For example, the exact Git revision of the specified branch for a Git Source.
name: Option<String>Name of the registry source for alternative registries WARNING: this is not always set for alt-registries when the name is not known.
alt_registry_key: Option<String>Name of the alt registry in the [registries] table.
WARNING: this is not always set for alt-registries when the name is
not known.