Struct cargo::ops::WorkspaceResolve
source · pub struct WorkspaceResolve<'cfg> {
pub pkg_set: PackageSet<'cfg>,
pub workspace_resolve: Option<Resolve>,
pub targeted_resolve: Resolve,
pub resolved_features: ResolvedFeatures,
}Expand description
Result for resolve_ws_with_opts.
Fields
pkg_set: PackageSet<'cfg>Packages to be downloaded.
workspace_resolve: Option<Resolve>The resolve for the entire workspace.
This may be None for things like cargo install and -Zavoid-dev-deps.
This does not include paths overrides.
targeted_resolve: ResolveThe narrowed resolve, with the specific features enabled, and only the given package specs requested.
resolved_features: ResolvedFeaturesThe features activated per package.