Struct cargo::ops::tree::TreeOptions
source · pub struct TreeOptions {Show 14 fields
pub cli_features: CliFeatures,
pub packages: Packages,
pub target: Target,
pub edge_kinds: HashSet<EdgeKind>,
pub invert: Vec<String>,
pub pkgs_to_prune: Vec<String>,
pub prefix: Prefix,
pub no_dedupe: bool,
pub duplicates: bool,
pub charset: Charset,
pub format: String,
pub graph_features: bool,
pub max_display_depth: u32,
pub no_proc_macro: bool,
}Fields
cli_features: CliFeaturespackages: PackagesThe packages to display the tree for.
target: TargetThe platform to filter for.
edge_kinds: HashSet<EdgeKind>The dependency kinds to display.
invert: Vec<String>pkgs_to_prune: Vec<String>The packages to prune from the display of the dependency tree.
prefix: PrefixThe style of prefix for each line.
no_dedupe: boolIf true, duplicates will be repeated.
If false, duplicates will be marked with *, and their dependencies
won’t be shown.
duplicates: boolIf true, run in a special mode where it will scan for packages that
appear with different versions, and report if any where found. Implies
invert.
charset: CharsetThe style of characters to use.
format: StringA format string indicating how each package should be displayed.
graph_features: boolIncludes features in the tree as separate nodes.
max_display_depth: u32Maximum display depth of the dependency tree.
no_proc_macro: boolExcludes proc-macro dependencies.