pub fn reinitialize(git_dir: &Path) -> CargoResult<()>Expand description
Reinitializes a given Git repository. This is useful when a Git repoistory seems corrupted and we want to start over.
pub fn reinitialize(git_dir: &Path) -> CargoResult<()>Reinitializes a given Git repository. This is useful when a Git repoistory seems corrupted and we want to start over.