pub enum MaybeLock {
Ready(File),
Download {
url: String,
descriptor: String,
authorization: Option<String>,
},
}Expand description
The status of RegistryData::download which indicates if a .crate
file has already been downloaded, or if not then the URL to download.
Variants
Ready(File)
The .crate file is already downloaded. File is a handle to the
opened .crate file on the filesystem.
Download
The .crate file is not downloaded, here’s the URL to download it from.
descriptor is just a text string to display to the user of what is
being downloaded.