pub struct Secret<T> { /* private fields */ }Expand description
A wrapper for values that should not be printed.
This type does not implement Display, and has a Debug impl that hides
the contained value.
let token = Secret::from("super secret string");
assert_eq!(format!("{:?}", token), "Secret { inner: \"REDACTED\" }");Currently, we write a borrowed Secret<T> as Secret<&T>.
The as_deref and owned methods can
be used to convert back and forth between Secret<String> and Secret<&str>.
Implementations
sourceimpl<T> Secret<T>
impl<T> Secret<T>
sourcepub fn expose(self) -> T
pub fn expose(self) -> T
Unwraps the contained value.
Use of this method marks the boundary of where the contained value is hidden.