Enum cargo::util::command_prelude::ProfileChecking
source · pub enum ProfileChecking {
LegacyRustc,
LegacyTestOnly,
Custom,
}Expand description
Determines whether or not to gate --profile as unstable when resolving it.
Variants
LegacyRustc
cargo rustc historically has allowed “test”, “bench”, and “check”. This
variant explicitly allows those.
LegacyTestOnly
cargo check and cargo fix historically has allowed “test”. This variant
explicitly allows that on stable.
Custom
All other commands, which allow any valid custom named profile.