Trait syn::parse::Parse [−][src]
pub trait Parse: Sized { fn parse(input: ParseStream<'_>) -> Result<Self>; }
Parsing interface implemented by all types that can be parsed in a default way from a token stream.
Refer to the module documentation for details about implementing and using
the Parse trait.
Required methods
fn parse(input: ParseStream<'_>) -> Result<Self>[src]
Implementations on Foreign Types
impl Parse for Option<BoundLifetimes>[src]
impl Parse for Option<BoundLifetimes>[src]fn parse(input: ParseStream<'_>) -> Result<Self>[src]
impl Parse for Option<WhereClause>[src]
impl Parse for Option<WhereClause>[src]fn parse(input: ParseStream<'_>) -> Result<Self>[src]
impl Parse for Option<Abi>[src]
impl Parse for Option<Abi>[src]fn parse(input: ParseStream<'_>) -> Result<Self>[src]
impl<T: Parse> Parse for Box<T>[src]
impl<T: Parse> Parse for Box<T>[src]fn parse(input: ParseStream<'_>) -> Result<Self>[src]
impl<T: Parse + Token> Parse for Option<T>[src]
impl<T: Parse + Token> Parse for Option<T>[src]fn parse(input: ParseStream<'_>) -> Result<Self>[src]
impl Parse for TokenStream[src]
impl Parse for TokenStream[src]fn parse(input: ParseStream<'_>) -> Result<Self>[src]
impl Parse for TokenTree[src]
impl Parse for TokenTree[src]fn parse(input: ParseStream<'_>) -> Result<Self>[src]
impl Parse for Group[src]
impl Parse for Group[src]fn parse(input: ParseStream<'_>) -> Result<Self>[src]
impl Parse for Punct[src]
impl Parse for Punct[src]fn parse(input: ParseStream<'_>) -> Result<Self>[src]
impl Parse for Literal[src]
impl Parse for Literal[src]fn parse(input: ParseStream<'_>) -> Result<Self>[src]
Implementors
impl Parse for GenericArgument[src]
impl Parse for GenericArgument[src]fn parse(input: ParseStream<'_>) -> Result<Self>[src]
impl Parse for GenericParam[src]
impl Parse for GenericParam[src]fn parse(input: ParseStream<'_>) -> Result<Self>[src]
impl Parse for NestedMeta[src]
impl Parse for NestedMeta[src]fn parse(input: ParseStream<'_>) -> Result<Self>[src]
impl Parse for ReturnType[src]
impl Parse for ReturnType[src]fn parse(input: ParseStream<'_>) -> Result<Self>[src]
impl Parse for TraitBoundModifier[src]
impl Parse for TraitBoundModifier[src]fn parse(input: ParseStream<'_>) -> Result<Self>[src]
impl Parse for TypeParamBound[src]
impl Parse for TypeParamBound[src]fn parse(input: ParseStream<'_>) -> Result<Self>[src]
impl Parse for Visibility[src]
impl Parse for Visibility[src]fn parse(input: ParseStream<'_>) -> Result<Self>[src]
impl Parse for WherePredicate[src]
impl Parse for WherePredicate[src]fn parse(input: ParseStream<'_>) -> Result<Self>[src]
impl Parse for AngleBracketedGenericArguments[src]
impl Parse for AngleBracketedGenericArguments[src]fn parse(input: ParseStream<'_>) -> Result<Self>[src]
impl Parse for BoundLifetimes[src]
impl Parse for BoundLifetimes[src]fn parse(input: ParseStream<'_>) -> Result<Self>[src]
impl Parse for ConstParam[src]
impl Parse for ConstParam[src]fn parse(input: ParseStream<'_>) -> Result<Self>[src]
impl Parse for DeriveInput[src]
impl Parse for DeriveInput[src]fn parse(input: ParseStream<'_>) -> Result<Self>[src]
impl Parse for FieldsNamed[src]
impl Parse for FieldsNamed[src]fn parse(input: ParseStream<'_>) -> Result<Self>[src]
impl Parse for FieldsUnnamed[src]
impl Parse for FieldsUnnamed[src]fn parse(input: ParseStream<'_>) -> Result<Self>[src]
impl Parse for LifetimeDef[src]
impl Parse for LifetimeDef[src]fn parse(input: ParseStream<'_>) -> Result<Self>[src]
impl Parse for LitByteStr[src]
impl Parse for LitByteStr[src]fn parse(input: ParseStream<'_>) -> Result<Self>[src]
impl Parse for MetaNameValue[src]
impl Parse for MetaNameValue[src]fn parse(input: ParseStream<'_>) -> Result<Self>[src]
impl Parse for ParenthesizedGenericArguments[src]
impl Parse for ParenthesizedGenericArguments[src]fn parse(input: ParseStream<'_>) -> Result<Self>[src]
impl Parse for PathSegment[src]
impl Parse for PathSegment[src]fn parse(input: ParseStream<'_>) -> Result<Self>[src]
impl Parse for TraitBound[src]
impl Parse for TraitBound[src]fn parse(input: ParseStream<'_>) -> Result<Self>[src]
impl Parse for TypeBareFn[src]
impl Parse for TypeBareFn[src]fn parse(input: ParseStream<'_>) -> Result<Self>[src]
impl Parse for TypeImplTrait[src]
impl Parse for TypeImplTrait[src]fn parse(input: ParseStream<'_>) -> Result<Self>[src]
impl Parse for TypeReference[src]
impl Parse for TypeReference[src]fn parse(input: ParseStream<'_>) -> Result<Self>[src]
impl Parse for TypeTraitObject[src]
impl Parse for TypeTraitObject[src]fn parse(input: ParseStream<'_>) -> Result<Self>[src]
impl Parse for WhereClause[src]
impl Parse for WhereClause[src]fn parse(input: ParseStream<'_>) -> Result<Self>[src]
impl Parse for Underscore[src]
impl Parse for Underscore[src]