Struct syn::ExprGroup [−][src]
pub struct ExprGroup { /* fields omitted */ }An expression contained within invisible delimiters.
This variant is important for faithfully representing the precedence
of expressions and is related to None-delimited spans in a
TokenStream.
This type is available only if Syn is built with the "full" feature.