Struct syn::ExprIf [−][src]
pub struct ExprIf { /* fields omitted */ }An if expression with an optional else block: if expr { ... } else { ... }.
The else branch expression may only be an If or Block
expression, not any of the other types of expression.
This type is available only if Syn is built with the "full" feature.