fn dirty_metadata_paths(
pkg: &Package,
repo: &Repository,
) -> CargoResult<Vec<PathBuf>>Expand description
Checks whether files at paths specified in package.readme and
package.license-file have been modified.
This is required because those paths may link to a file outside the
current package root, but still under the git workdir, affecting the
final packaged .crate file.