Enum cargo::ops::CommandType
[−]
[src]
pub enum CommandType {
Rustc,
Rustdoc,
Target(OsString),
Host(OsString),
}Variants
Rustc | |
Rustdoc | |
Target | The command is to be executed for the target architecture. |
Host | The command is to be executed for the host architecture. |