Packages

Enum Packages 

pub enum Packages {
    Default,
    All,
    OptOut(Vec<String>),
    Packages(Vec<String>),
}

Variants



Default



All



OptOut(Vec<String>)



Packages(Vec<String>)

Implementations

Source

impl Packages

pub fn from_flags( all: bool, exclude: Vec<String>, package: Vec<String>, ) -> CargoResult<Self>

pub fn to_package_id_specs( &self, ws: &Workspace<'_>, ) -> CargoResult<Vec<PackageIdSpec>>

pub fn get_packages<'ws>( &self, ws: &'ws Workspace<'_>, ) -> CargoResult<Vec<&'ws Package>>

pub fn needs_spec_flag(&self, ws: &Workspace<'_>) -> bool

Returns whether or not the user needs to pass a -p flag to target a specific package in the workspace.