CleanOptions

Struct CleanOptions 

pub struct CleanOptions<'a> {
    pub config: &'a Config,
    pub spec: Vec<String>,
    pub target: Option<String>,
    pub profile_specified: bool,
    pub requested_profile: InternedString,
    pub doc: bool,
}

Fields

config: &'a Configspec: Vec<String>

A list of packages to clean. If empty, everything is cleaned.

target: Option<String>

The target arch triple to clean, or None for the host arch

profile_specified: bool

Whether to clean the release directory

requested_profile: InternedString

Whether to clean the directory of a certain build profile

doc: bool

Whether to just clean the doc directory