Struct cargo::sources::directory::DirectorySource
source · pub struct DirectorySource<'cfg> { /* private fields */ }Expand description
DirectorySource contains a number of crates on the file system. It was
designed for representing vendored dependencies for cargo vendor.
DirectorySource at this moment is just a root directory containing other
directories, which contain the source files of packages. Assumptions would
be made to determine if a directory should be included as a package of a
directory source’s:
- Ignore directories starting with dot
.(tend to be hidden). - Only when a
Cargo.tomlexists in a directory will it be included as a package.DirectorySourceat this time only looks at one level of directories and never went deeper. - There must be a [
Checksum] file.cargo-checksum.jsonfile at the same level ofCargo.tomlto ensure the integrity when a directory source was created (usually bycargo vendor). A failure to find or parse a single checksum results in a denial of loading any package in this source. - Otherwise, there is no other restrction of the name of directories. At
this moment, it is
cargo vendorthat defines the layout and the name of each directory.
The file tree of a directory source may look like:
[source root]
├── a-valid-crate/
│ ├── src/
│ ├── .cargo-checksum.json
│ └── Cargo.toml
├── .ignored-a-dot-crate/
│ ├── src/
│ ├── .cargo-checksum.json
│ └── Cargo.toml
├── skipped-no-manifest/
│ ├── src/
│ └── .cargo-checksum.json
└── no-checksum-so-fails-the-entire-source-reading/
└── Cargo.toml
Implementations
sourceimpl<'cfg> DirectorySource<'cfg>
impl<'cfg> DirectorySource<'cfg>