Struct cargo::sources::git::GitCheckout
[−]
[src]
pub struct GitCheckout<'a> {
// some fields omitted
}GitCheckout is a local checkout of a particular revision. Calling
clone_into with a reference will resolve the reference into a revision,
and return a CargoError if no revision for that reference was found.