pub enum Definition {
Path(PathBuf),
Environment(String),
Cli,
}Expand description
Location where a config value is defined.
Variants
Path(PathBuf)
Defined in a .cargo/config, includes the path to the file.
Environment(String)
Defined in an environment variable, includes the environment key.
Cli
Passed in on the command line.
Implementations
Sourceimpl Definition
impl Definition
Sourcepub fn root<'a>(&'a self, config: &'a Config) -> &'a Path
pub fn root<'a>(&'a self, config: &'a Config) -> &'a Path
Root directory where this is defined.
If from a file, it is the directory above .cargo/config.
CLI and env are the current working directory.
Sourcepub fn is_higher_priority(&self, other: &Definition) -> bool
pub fn is_higher_priority(&self, other: &Definition) -> bool
Returns true if self is a higher priority to other.
CLI is preferred over environment, which is preferred over files.