PathAndArgs

Struct PathAndArgs 

pub struct PathAndArgs {
    pub path: ConfigRelativePath,
    pub args: Vec<String>,
}
A config type that is a program to run.

This supports a list of strings like ['/path/to/program', 'somearg'] or a space separated string like '/path/to/program somearg'.

This expects the first value to be the path to the program to run. Subsequent values are strings of arguments to pass to the program.

Typically you should use ConfigRelativePath::resolve_program on the path to get the actual program.

Fields

path: ConfigRelativePathargs: Vec<String>