pub struct StringList(/* private fields */);Expand description
A type to deserialize a list of strings from a toml file.
Supports deserializing either a whitespace-separated list of arguments in a single string or a string list itself. For example these deserialize to equivalent values:
a = 'a b c'
b = ['a', 'b', 'c']Implementations