Struct cargo::util::toml::Layout
[−]
[src]
pub struct Layout {
pub root: PathBuf,
// some fields omitted
}Representation of the projects file layout.
This structure is used to hold references to all project files that are relevant to cargo.
Fields
root |
Methods
impl Layout[src]
fn from_project_path(root_path: &Path) -> Layout
Returns a new Layout for a given root path.
The root_path represents the directory that contains the Cargo.toml file.