pub struct TomlProject { /* private fields */ }Expand description
Represents the package/project sections of a Cargo.toml.
Note that the order of the fields matters, since this is the order they
are serialized to a TOML file. For example, you cannot have values after
the field metadata, since it is a table and values cannot appear after
tables.
Implementations
Sourceimpl TomlProject
impl TomlProject
pub fn to_package_id(&self, source_id: SourceId) -> CargoResult<PackageId>