pub struct PackageSet<'cfg> { /* private fields */ }Expand description
A set of packages, with the intent to download.
This is primarily used to convert a set of PackageIds to Packages. It
will download as needed, or used the cached download if available.
Implementations
Sourceimpl<'cfg> PackageSet<'cfg>
impl<'cfg> PackageSet<'cfg>
pub fn new( package_ids: &[PackageId], sources: SourceMap<'cfg>, config: &'cfg Config, ) -> CargoResult<PackageSet<'cfg>>
pub fn package_ids<'a>(&'a self) -> impl Iterator<Item = PackageId> + 'a
pub fn enable_download<'a>(&'a self) -> CargoResult<Downloads<'a, 'cfg>>
pub fn get_one(&self, id: PackageId) -> CargoResult<&Package>
pub fn get_many( &self, ids: impl IntoIterator<Item = PackageId>, ) -> CargoResult<Vec<&Package>>
Sourcepub fn download_accessible(
&self,
resolve: &Resolve,
root_ids: &[PackageId],
has_dev_units: HasDevUnits,
requested_kind: CompileKind,
target_data: &RustcTargetData,
) -> CargoResult<()>
pub fn download_accessible( &self, resolve: &Resolve, root_ids: &[PackageId], has_dev_units: HasDevUnits, requested_kind: CompileKind, target_data: &RustcTargetData, ) -> CargoResult<()>
Downloads any packages accessible from the give root ids.
pub fn sources(&self) -> Ref<'_, SourceMap<'cfg>>
pub fn sources_mut(&self) -> RefMut<'_, SourceMap<'cfg>>
Sourcepub fn add_set(&mut self, set: PackageSet<'cfg>)
pub fn add_set(&mut self, set: PackageSet<'cfg>)
Merge the given set into self.
Sourcepub fn lookup_mut(&mut self, id: PackageId) -> Option<&mut Package>
pub fn lookup_mut(&mut self, id: PackageId) -> Option<&mut Package>
Get mutable access to an already downloaded package, if it’s already downoaded and it’s part of this set. Does not actually attempt to download anything if it’s not already downloaded.