Struct cargo::ops::CleanOptions
source · pub struct CleanOptions<'a> {
pub config: &'a Config,
pub spec: Vec<String>,
pub targets: Vec<String>,
pub profile_specified: bool,
pub requested_profile: InternedString,
pub doc: bool,
}Fields
config: &'a Configspec: Vec<String>A list of packages to clean. If empty, everything is cleaned.
targets: Vec<String>The target arch triple to clean, or None for the host arch
profile_specified: boolWhether to clean the release directory
requested_profile: InternedStringWhether to clean the directory of a certain build profile
doc: boolWhether to just clean the doc directory