pub struct GitCheckout<'a> { /* private fields */ }Expand description
GitCheckout is a local checkout of a particular revision. Calling
clone_into with a reference will resolve the reference into a revision,
and return a anyhow::Error if no revision for that reference was found.