pub struct TargetConfig {
pub runner: OptValue<PathAndArgs>,
pub rustflags: OptValue<StringList>,
pub linker: OptValue<ConfigRelativePath>,
pub links_overrides: BTreeMap<String, BuildOutput>,
}Expand description
Config definition of a [target] table.
Fields
runner: OptValue<PathAndArgs>Process to run as a wrapper for cargo run, test, and bench commands.
rustflags: OptValue<StringList>Additional rustc flags to pass.
linker: OptValue<ConfigRelativePath>The path of the linker for this target.
links_overrides: BTreeMap<String, BuildOutput>Build script override for the given library name.
Any package with a links value for the given library name will skip
running its build script and instead use the given output from the
config file.