pub struct ArtifactProfile {
pub opt_level: &'static str,
pub debuginfo: Option<u32>,
pub debug_assertions: bool,
pub overflow_checks: bool,
pub test: bool,
}Expand description
This is different from the regular Profile to maintain backwards
compatibility (in particular, test is no longer in Profile, but we
still want it to be included here).
Fields
opt_level: &'static strdebuginfo: Option<u32>debug_assertions: booloverflow_checks: booltest: boolTrait Implementations